#!/usr/bin/env python
# vim: set expandtab tabstop=4 shiftwidth=4:
#
# UQM Starmap Viewer
# Copyright (C) 2009 CJ Kucera
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

import cPickle
import MySQLdb
import ConfigParser

# This tiny app doesn't really do anyone any good except for me.  I had
# pulled the map data from UQM into a MySQL database and stored it there
# for awhile - originally the starmap viewer was actually going to do
# all of its filtering and stuff via SQL, though when I started the project
# I never did more than the basic SELECTs you see below, and then did
# all the work via the classes, like the app still does.  Then when I
# thought about the fact that I may want to distribute this somehow, having
# a MySQL dependency was just ludicrous.  So, I ripped out what little
# there was of the DB connectivity and slapped it in here, exporting the
# data to a Pickle object instead, which is how the main app reads it.
#
# ... I know you TOTALLY care about all that.  Anyway, it's here for
# posterity, in case anyone was wondering how the initial pickle had been
# generated.

cp = ConfigParser.ConfigParser()
cp.read('dbinfo.txt')

dbconn = MySQLdb.connect(host = cp.get('db', 'host'),
        user = cp.get('db', 'user'),
        passwd = cp.get('db', 'pass'),
        db = cp.get('db', 'db'))
dbcurs = dbconn.cursor(MySQLdb.cursors.DictCursor)

data = {}

dbcurs.execute('select * from system')
data['systems'] = dbcurs.fetchall()

dbcurs.execute('select * from planet')
data['planets'] = dbcurs.fetchall()

dbcurs.close()
dbconn.close()

# Hardcode quasispace points
data['quasispace'] = (
        { 'label': 'A', 'x': 438, 'y': 6373, 'qs_x': 500, 'qs_y': 500 },
        { 'label': 'B', 'x': 111, 'y': 9409, 'qs_x': 520, 'qs_y': 514 },
        { 'label': 'C', 'x': 5849, 'y': 6213, 'qs_x': 520, 'qs_y': 540 },
        { 'label': 'D', 'x': 7752, 'y': 8906, 'qs_x': 530, 'qs_y': 528 },
        { 'label': 'E', 'x': 368, 'y': 6332, 'qs_x': 544, 'qs_y': 532 },
        { 'label': 'F', 'x': 3183, 'y': 4906, 'qs_x': 502, 'qs_y': 460 },
        { 'label': 'G', 'x': 1909, 'y': 926, 'qs_x': 506, 'qs_y': 474 },
        { 'label': 'H', 'x': 5673, 'y': 1207, 'qs_x': 516, 'qs_y': 466 },
        { 'label': 'I', 'x': 4090, 'y': 7748, 'qs_x': 476, 'qs_y': 458 },
        { 'label': 'J', 'x': 9210, 'y': 6104, 'qs_x': 468, 'qs_y': 464 },
        { 'label': 'K', 'x': 6116, 'y': 4131, 'qs_x': 476, 'qs_y': 496 },
        { 'label': 'L', 'x': 2302, 'y': 3988, 'qs_x': 466, 'qs_y': 514 },
        { 'label': 'M', 'x': 5657, 'y': 9712, 'qs_x': 448, 'qs_y': 504 },
        { 'label': 'N', 'x': 8607, 'y': 151, 'qs_x': 458, 'qs_y': 492 },
        { 'label': 'O', 'x': 50, 'y': 1647, 'qs_x': 492, 'qs_y': 492 },
        { 'label': 'P', 'x': 9735, 'y': 3153, 'qs_x': 488, 'qs_y': 538 }
    )

# Now let's import our constellation data; note that we're going
# to do some associations here...  We do it here so that the main
# app doesn't have to, and because our IDs may change at some point
# in the future.
ids = {}
data['constellations'] = {}
for system in data['systems']:
    if (system['position'] and system['position'] != ''):
        sysname = system['name'].lower()
        syspos = system['position'].lower()
        if not sysname in ids:
            ids[sysname] = {}
        ids[sysname][syspos] = system['sid']
cp = ConfigParser.ConfigParser()
cp.read('constellations.ini')
for const in cp.sections():
    for (star, links) in cp.items(const):
        const = const.lower()
        star = star.lower()
        if (const in ids and star in ids[const]):
            data['constellations'][ids[const][star]] = []
            for link in links.split(','):
                link = link.lower()
                if (const in ids and link in ids[const]):
                    data['constellations'][ids[const][star]].append(ids[const][link])
                else:
                    print 'No ID for link %s %s!' % (link, const)
        else:
            print 'No ID for starting point %s %s!' % (star, const)

df = open('data.pickle', 'w')
cPickle.dump(data, df)
df.close()
